@@ -7,6 +7,7 @@ from anypoint.api.api_manager import ApiManagerApi
 from anypoint.api.application import ApplicationApi
 from anypoint.api.environment import EnvironmentApi
 from anypoint.api.monitoring import MonitoringApi
+from anypoint.api.mq import MQApi
 from anypoint.api.organization import OrganizationApi
 from anypoint.authentication import Authentication
 from anypoint.http_client.client import HttpClient
@@ -29,6 +30,7 @@ class Anypoint:
         self.environments = EnvironmentApi(self, log)
         self.monitoring = MonitoringApi(self, log)
         self.api_manager = ApiManagerApi(self, log)
+        self.mq = MQApi(self, log)
 
         self._log = log
         self._access_token: Optional[str] = None
